/*
 * Copyright 2021 NXP
 * SPDX-License-Identifier: MIT
 */

#ifndef GUI_GUIDER_H
#define GUI_GUIDER_H
#ifdef __cplusplus
extern "C" {
#endif

#include "lvgl/lvgl.h"
#include "guider_fonts.h"

typedef struct
{
	lv_obj_t *screWelcome;
	lv_obj_t *screWelcome_contBackground;
	lv_obj_t *screWelcome_imgHead;
	lv_obj_t *screWelcome_imgHomeLogo;
	lv_obj_t *screWelcome_labelWelcomeSlogan;
	lv_obj_t *screWelcome_labelTime;
	lv_obj_t *screWelcome_contTodayInfo;
	lv_obj_t *screWelcome_imgMaxTempDegree;
	lv_obj_t *screWelcome_imgMinTempDegree;
	lv_obj_t *screWelcome_labelMaxTemp;
	lv_obj_t *screWelcome_labelSeparator;
	lv_obj_t *screWelcome_labelMinTemp;
	lv_obj_t *screWelcome_labelWeatherDesc;
	lv_obj_t *screWelcome_imgWeather;
	lv_obj_t *screWelcome_imgDegree;
	lv_obj_t *screWelcome_labelCurrentTemp;
	lv_obj_t *screWelcome_labelDate;
	lv_obj_t *screWelcome_imgbtnTemp;
	lv_obj_t *screWelcome_imgbtnTemp_label;
	lv_obj_t *screWelcome_imgbtnLight;
	lv_obj_t *screWelcome_imgbtnLight_label;
	lv_obj_t *screWelcome_imgbtnSecurity;
	lv_obj_t *screWelcome_imgbtnSecurity_label;
	lv_obj_t *screWelcome_imgbtnMusic;
	lv_obj_t *screWelcome_imgbtnMusic_label;
	lv_obj_t *screWelcome_labelTemp;
	lv_obj_t *screWelcome_labelLight;
	lv_obj_t *screWelcome_labelSecurity;
	lv_obj_t *screWelcome_labelAudioPlayer;
	lv_obj_t *screenTemp;
	lv_obj_t *screenTemp_contBackground;
	lv_obj_t *screenTemp_imgHead;
	lv_obj_t *screenTemp_labelTempSlogan;
	lv_obj_t *screenTemp_labelTime;
	lv_obj_t *screenTemp_imgbtnCold;
	lv_obj_t *screenTemp_imgbtnCold_label;
	lv_obj_t *screenTemp_imgbtnAuto;
	lv_obj_t *screenTemp_imgbtnAuto_label;
	lv_obj_t *screenTemp_imgbtnFire;
	lv_obj_t *screenTemp_imgbtnFire_label;
	lv_obj_t *screenTemp_arcTempControl;
	lv_obj_t *screenTemp_imgbtnHome;
	lv_obj_t *screenTemp_imgbtnHome_label;
	lv_obj_t *screenTemp_imgbtnTempOff;
	lv_obj_t *screenTemp_imgbtnTempOff_label;
	lv_obj_t *screenTemp_sliderFanSpeed;
	lv_obj_t *screenTemp_imgFan;
	lv_obj_t *screenTemp_imgTempBackground;
	lv_obj_t *screenTemp_imgbtnTempUp;
	lv_obj_t *screenTemp_imgbtnTempUp_label;
	lv_obj_t *screenTemp_imgbtnTempDown;
	lv_obj_t *screenTemp_imgbtnTempDown_label;
	lv_obj_t *screenTemp_labelTempSet;
	lv_obj_t *screenTemp_labelTempDegree;
	lv_obj_t *screLight;
	lv_obj_t *screLight_contBackground;
	lv_obj_t *screLight_imgHead;
	lv_obj_t *screLight_imgbtnHome;
	lv_obj_t *screLight_imgbtnHome_label;
	lv_obj_t *screLight_swCeiling;
	lv_obj_t *screLight_swLamps;
	lv_obj_t *screLight_swReading;
	lv_obj_t *screLight_labelCeiling;
	lv_obj_t *screLight_labelLamp;
	lv_obj_t *screLight_labelReading;
	lv_obj_t *screLight_sliderCeiling;
	lv_obj_t *screLight_sliderLamps;
	lv_obj_t *screLight_imgbtnPalette;
	lv_obj_t *screLight_imgbtnPalette_label;
	lv_obj_t *screLight_sliderReading;
	lv_obj_t *screLight_ddlistLight;
	lv_obj_t *screLight_lineSeparator;
	lv_obj_t *screLight_imgbtnAllLightOn;
	lv_obj_t *screLight_imgbtnAllLightOn_label;
	lv_obj_t *screLight_imgbtnAllLightOff;
	lv_obj_t *screLight_imgbtnAllLightOff_label;
	lv_obj_t *screLight_imgbtnMovie;
	lv_obj_t *screLight_imgbtnMovie_label;
	lv_obj_t *screLight_imgbtnParty;
	lv_obj_t *screLight_imgbtnParty_label;
	lv_obj_t *screLight_labelLightSlogan;
	lv_obj_t *screLight_labelTime;
	lv_obj_t *screSecurityhome;
	lv_obj_t *screSecurityhome_contBackground;
	lv_obj_t *screSecurityhome_btnArm;
	lv_obj_t *screSecurityhome_btnArm_label;
	lv_obj_t *screSecurityhome_img_1;
	lv_obj_t *screSecurityhome_imgbtnHome;
	lv_obj_t *screSecurityhome_imgbtnHome_label;
	lv_obj_t *screSecurityhome_labelTime;
	lv_obj_t *screSecurityhome_labelSecurityCtrl;
	lv_obj_t *screSecurityhome_swFDoor;
	lv_obj_t *screSecurityhome_swBDoor;
	lv_obj_t *screSecurityhome_swGDoor;
	lv_obj_t *screSecurityhome_labelFDoor;
	lv_obj_t *screSecurityhome_labelBDoor;
	lv_obj_t *screSecurityhome_labelGDoor;
	lv_obj_t *screSecurityhome_labelArmed;
	lv_obj_t *screSecurityhome_imgLock;
	lv_obj_t *screSecurityhome_contDivLineHL;
	lv_obj_t *screSecurityhome_contDivLineHR;
	lv_obj_t *screSecurityhome_contDivLineVL;
	lv_obj_t *screSecurityhome_contDivLineVR;
	lv_obj_t *screSecurity;
	lv_obj_t *screSecurity_contBackground;
	lv_obj_t *screSecurity_imgHead;
	lv_obj_t *screSecurity_imgbtnHome;
	lv_obj_t *screSecurity_imgbtnHome_label;
	lv_obj_t *screSecurity_labelSecurity;
	lv_obj_t *screSecurity_btnNum1;
	lv_obj_t *screSecurity_btnNum1_label;
	lv_obj_t *screSecurity_btnNum2;
	lv_obj_t *screSecurity_btnNum2_label;
	lv_obj_t *screSecurity_btnNum3;
	lv_obj_t *screSecurity_btnNum3_label;
	lv_obj_t *screSecurity_btnNum4;
	lv_obj_t *screSecurity_btnNum4_label;
	lv_obj_t *screSecurity_btnNum5;
	lv_obj_t *screSecurity_btnNum5_label;
	lv_obj_t *screSecurity_btnNum6;
	lv_obj_t *screSecurity_btnNum6_label;
	lv_obj_t *screSecurity_btnNum7;
	lv_obj_t *screSecurity_btnNum7_label;
	lv_obj_t *screSecurity_btnNum8;
	lv_obj_t *screSecurity_btnNum8_label;
	lv_obj_t *screSecurity_btnNum9;
	lv_obj_t *screSecurity_btnNum9_label;
	lv_obj_t *screSecurity_btnNumDel;
	lv_obj_t *screSecurity_btnNumDel_label;
	lv_obj_t *screSecurity_btnNum0;
	lv_obj_t *screSecurity_btnNum0_label;
	lv_obj_t *screSecurity_btnNumOk;
	lv_obj_t *screSecurity_btnNumOk_label;
	lv_obj_t *screSecurity_labelEnterPinStr;
	lv_obj_t *screSecurity_linePinLine1;
	lv_obj_t *screSecurity_linePinLine2;
	lv_obj_t *screSecurity_linePinLine3;
	lv_obj_t *screSecurity_linePinLine4;
	lv_obj_t *screSecurity_labelPinNum1;
	lv_obj_t *screSecurity_labelPinNum2;
	lv_obj_t *screSecurity_labelPinNum3;
	lv_obj_t *screSecurity_labelPinNum4;
	lv_obj_t *screSecurity_labelTime;
	lv_obj_t *SrceSecurityPasswordOK;
	lv_obj_t *SrceSecurityPasswordOK_cont_1;
	lv_obj_t *SrceSecurityPasswordOK_img_1;
	lv_obj_t *screAudio;
	lv_obj_t *screAudio_contBackground;
	lv_obj_t *screAudio_imgHead;
	lv_obj_t *screAudio_labelAudioSlogan;
	lv_obj_t *screAudio_labelTime;
	lv_obj_t *screAudio_imgbtnAudioNext;
	lv_obj_t *screAudio_imgbtnAudioNext_label;
	lv_obj_t *screAudio_imgbtnAudioPre;
	lv_obj_t *screAudio_imgbtnAudioPre_label;
	lv_obj_t *screAudio_arcAudioControl;
	lv_obj_t *screAudio_imgbtnHome;
	lv_obj_t *screAudio_imgbtnHome_label;
	lv_obj_t *screAudio_contBackspeaker;
	lv_obj_t *screAudio_imgbtnAudioSel;
	lv_obj_t *screAudio_imgbtnAudioSel_label;
	lv_obj_t *screAudio_sliderSpeakerVol;
	lv_obj_t *screAudio_imgSpeaker;
	lv_obj_t *screAudio_imgAudioBackground;
	lv_obj_t *screAudio_imgbtnAudioPlay;
	lv_obj_t *screAudio_imgbtnAudioPlay_label;
	lv_obj_t *screAudio_labelSongname;
	lv_obj_t *screAudio_imgAudioBackground_1;
	lv_obj_t *screAudio_imgAudioBackground_2;
	lv_obj_t *screAudio_imgbtnAudioPause;
	lv_obj_t *screAudio_imgbtnAudioPause_label;
	lv_obj_t *screAudioList;
	lv_obj_t *screAudioList_contBackground;
	lv_obj_t *screAudioList_listSong;
	lv_obj_t *screAudioList_listSong_item0;
	lv_obj_t *screAudioList_listSong_item1;
	lv_obj_t *screAudioList_listSong_item2;
	lv_obj_t *screAudioList_imgHead;
	lv_obj_t *screAudioList_labelAudioListSlogan;
	lv_obj_t *screAudioList_labelTime;
	lv_obj_t *screAudioList_imgbtnHome;
	lv_obj_t *screAudioList_imgbtnHome_label;
	lv_obj_t *screAudioList_imgbtnAudioList;
	lv_obj_t *screAudioList_imgbtnAudioList_label;
	lv_obj_t *screAudioList_labelSongNo1;
	lv_obj_t *screAudioList_labelSongNo2;
	lv_obj_t *screAudioList_labelSongNo3;
	lv_obj_t *screAudioList_labelSongAlbum1;
	lv_obj_t *screAudioList_labelSongAlbum2;
	lv_obj_t *screAudioList_labelSongAlbum3;
	lv_obj_t *screAudioList_labelSongtime3;
	lv_obj_t *screAudioList_labelSongtime1;
	lv_obj_t *screAudioList_labelSongtime2;
	lv_obj_t *screAllLightOffConfirm;
	lv_obj_t *screAllLightOffConfirm_contBackground;
	lv_obj_t *screAllLightOffConfirm_contConfirmBackground;
	lv_obj_t *screAllLightOffConfirm_labelConfirm;
	lv_obj_t *screAllLightOffConfirm_imgbtnCheck;
	lv_obj_t *screAllLightOffConfirm_imgbtnCheck_label;
	lv_obj_t *screAllLightOffConfirm_imgbtnDeny;
	lv_obj_t *screAllLightOffConfirm_imgbtnDeny_label;
}lv_ui;

void setup_ui(lv_ui *ui);
extern lv_ui guider_ui;
void setup_scr_screWelcome(lv_ui *ui);
void setup_scr_screenTemp(lv_ui *ui);
void setup_scr_screLight(lv_ui *ui);
void setup_scr_screSecurityhome(lv_ui *ui);
void setup_scr_screSecurity(lv_ui *ui);
void setup_scr_SrceSecurityPasswordOK(lv_ui *ui);
void setup_scr_screAudio(lv_ui *ui);
void setup_scr_screAudioList(lv_ui *ui);
void setup_scr_screAllLightOffConfirm(lv_ui *ui);
LV_IMG_DECLARE(_btn_small_bg_alpha_50x50);
LV_IMG_DECLARE(_btn_ok_alpha_80x80);
LV_IMG_DECLARE(_icn_arrow_down_alpha_60x30);
LV_IMG_DECLARE(_btn_small_bg_cinema_alpha_50x50);
LV_IMG_DECLARE(_btn_big_bg_forward_alpha_51x52);
LV_IMG_DECLARE(_btn_small_bg_snow_alpha_55x55);
LV_IMG_DECLARE(_gutar_53x53);
LV_IMG_DECLARE(_btn_long_button_list_close_alpha_49x48);
LV_IMG_DECLARE(_btn_small_bg_auto_alpha_55x55);
LV_IMG_DECLARE(_btn_big_bg_alpha_150x150);
LV_IMG_DECLARE(_icn_arm_alpha_72x68);
LV_IMG_DECLARE(_img_album_1_small_53x53);
LV_IMG_DECLARE(_btn_small_bg_fire_alpha_55x55);
LV_IMG_DECLARE(_btn_big_bg_temp_alpha_70x70);
LV_IMG_DECLARE(_pause_alpha_48x48);
LV_IMG_DECLARE(_DegreeTrans_alpha_10x10);
LV_IMG_DECLARE(_btn_big_bg_secure_alpha_70x70);
LV_IMG_DECLARE(_color_table_alpha_140x140);
LV_IMG_DECLARE(_btn_small_bg_allLightOn_alpha_50x50);
LV_IMG_DECLARE(_img_header_alpha_480x80);
LV_IMG_DECLARE(_icn_p_cloud_alpha_40x40);
LV_IMG_DECLARE(_btn_big_bg_backward_alpha_51x52);
LV_IMG_DECLARE(_btn_big_bg_light_alpha_70x70);
LV_IMG_DECLARE(_icn_arrow_up_alpha_60x30);
LV_IMG_DECLARE(_btn_long_button_list_alpha_49x48);
LV_IMG_DECLARE(_btn_big_bg_audio_player_alpha_70x70);
LV_IMG_DECLARE(_icn_house_small_alpha_40x26);
LV_IMG_DECLARE(_icn_fan_alpha_20x20);
LV_IMG_DECLARE(_btn_play_alpha_48x48);
LV_IMG_DECLARE(_album2_alpha_120x120);
LV_IMG_DECLARE(_img_album_1_big_alpha_120x120);
LV_IMG_DECLARE(_inc_sound_alpha_20x20);
LV_IMG_DECLARE(_btn_small_bg_allLightOff_alpha_50x50);
LV_IMG_DECLARE(_nxp_smart_home_10_alpha_480x272);
LV_IMG_DECLARE(_btn_long_button_alpha_55x50);
LV_IMG_DECLARE(_btn_no_alpha_80x80);
LV_IMG_DECLARE(_btn_long_top_house_alpha_55x50);
LV_IMG_DECLARE(_DegreeTrans_alpha_6x6);
LV_IMG_DECLARE(_album2_53x53);
LV_IMG_DECLARE(_gutar_alpha_120x120);

#ifdef __cplusplus
}
#endif
#endif